pub struct ModuleRegistry { /* private fields */ }Expand description
Module registry for managing module lifecycle
Implementations
Sourceimpl ModuleRegistry
impl ModuleRegistry
Sourcepub fn discover_modules(&mut self) -> Result<Vec<ModuleInfo>>
pub fn discover_modules(&mut self) -> Result<Vec<ModuleInfo>>
Discover available modules in the modules directory
Sourcepub fn get_module(
&self,
name: &str,
version: Option<&str>,
) -> Result<ModuleInfo>
pub fn get_module( &self, name: &str, version: Option<&str>, ) -> Result<ModuleInfo>
Get module by name and optional version
Sourcepub fn install_module(&mut self, source: ModuleSource) -> Result<ModuleInfo>
pub fn install_module(&mut self, source: ModuleSource) -> Result<ModuleInfo>
Install module from source
Sourcepub fn update_module(
&mut self,
name: &str,
new_version: Option<&str>,
) -> Result<ModuleInfo>
pub fn update_module( &mut self, name: &str, new_version: Option<&str>, ) -> Result<ModuleInfo>
Update module to new version (re-pull from git if from git, else re-download from registry)
Sourcepub fn remove_module(&mut self, name: &str) -> Result<()>
pub fn remove_module(&mut self, name: &str) -> Result<()>
Remove module from disk.
Callers with a running node should stop the module first via ModuleLifecycle::stop_module.
Sourcepub fn list_modules(&self) -> Vec<ModuleInfo>
pub fn list_modules(&self) -> Vec<ModuleInfo>
List all installed modules
Sourcepub fn resolve_dependencies(
&self,
module_names: &[String],
) -> Result<Vec<ModuleInfo>>
pub fn resolve_dependencies( &self, module_names: &[String], ) -> Result<Vec<ModuleInfo>>
Resolve dependencies for a set of modules using the cached discovery snapshot.
Call discover_modules after install/remove so the cache is current.