Module bootstrap

Module bootstrap 

Module bootstrap from environment.

When the node spawns a module, it passes MODULE_ID, SOCKET_PATH, and DATA_DIR via environment variables. Use ModuleBootstrap::from_env() to read them—no clap needed.

Structs

ModuleBootstrap
Bootstrap parameters for a module, read from environment.

Traits

ModuleConfig
Config types that can be loaded and converted to context map. Use impl_module_config!(ConfigType) to implement by delegating to inherent load and to_context_map.