Module cli_args

Module cli_args 

CLI argument parsing and type coercion for module commands.

Parses ["--key", "value", "-n", "2"] into a map and coerces values to handler types.

Functions

coerce_bool
Coerce a string value to the target type.
parse_args
Parse CLI args into a map keyed by param name.