IPC Client
Re-export from blvm-node.
Client-side IPC implementation that modules use to communicate with the node.
Structs
- Module
IpcClient - IPC client for modules to communicate with node
IPC Client
Re-export from blvm-node.
Client-side IPC implementation that modules use to communicate with the node.